Print

Print


Commit in hps-java/src/main/java/org/lcsim/hps/recon/ecal on MAIN
ECalSimpleReadout.java-11.1 -> 1.2
HPSEcalReadoutDriver.java+6-61.1 -> 1.2
HPSEcal1BitClusterer.java+6-101.7 -> 1.8
+12-17
3 modified files
minor cleanup

hps-java/src/main/java/org/lcsim/hps/recon/ecal
ECalSimpleReadout.java 1.1 -> 1.2
diff -u -r1.1 -r1.2
--- ECalSimpleReadout.java	23 Aug 2011 17:08:10 -0000	1.1
+++ ECalSimpleReadout.java	23 Aug 2011 17:28:19 -0000	1.2
@@ -12,7 +12,6 @@
 import org.lcsim.event.CalorimeterHit;
 import org.lcsim.geometry.Subdetector;
 import org.lcsim.geometry.IDDecoder;
-import org.lcsim.hps.recon.ecal.RawCalorimeterHit;
 
 /**
  * Minimal ECal readout - just integrates energies of all hits, 

hps-java/src/main/java/org/lcsim/hps/recon/ecal
HPSEcalReadoutDriver.java 1.1 -> 1.2
diff -u -r1.1 -r1.2
--- HPSEcalReadoutDriver.java	23 Aug 2011 17:08:10 -0000	1.1
+++ HPSEcalReadoutDriver.java	23 Aug 2011 17:28:19 -0000	1.2
@@ -23,7 +23,7 @@
     HPSEcal ecal;
     String ecalCollectionName;
     String ecalName;
-    String digitizedCollectionName = "EcalDigitizedHits";
+    String rawCollectionName = "EcalRawHits";
     Map<Long, Double> eDepMap = null;
     int hitType = 11;
     //counts bunches for trigger clock
@@ -34,8 +34,8 @@
     public HPSEcalReadoutDriver() {
     }
 
-    public void setDigitizedCollectionName(String digitizedCollectionName) {
-        this.digitizedCollectionName = digitizedCollectionName;
+    public void setRawCollectionName(String rawCollectionName) {
+        this.rawCollectionName = rawCollectionName;
     }
 
     public void setEcalCollectionName(String ecalCollectionName) {
@@ -93,13 +93,13 @@
         if (clock % triggerCycle == 0) {
             IDDecoder dec = ecal.getIDDecoder();
             // New CalorimeterHit list to be added to event.
-            List<CalorimeterHit> digitizedHits = new ArrayList<CalorimeterHit>();
+            List<CalorimeterHit> rawHits = new ArrayList<CalorimeterHit>();
             for (Long cellID : eDepMap.keySet()) {
                 dec.setID(cellID);
-                digitizedHits.add(new RawCalorimeterHit(eDepMap.get(cellID), dec.getPosition(), 0.0, cellID, hitType, dec));
+                rawHits.add(new RawCalorimeterHit(eDepMap.get(cellID), dec.getPosition(), 0.0, cellID, hitType, dec));
             }
 
-            event.put(digitizedCollectionName, digitizedHits, CalorimeterHit.class, 0);
+            event.put(rawCollectionName, rawHits, CalorimeterHit.class, 0);
         }
     }
 }
\ No newline at end of file

hps-java/src/main/java/org/lcsim/hps/recon/ecal
HPSEcal1BitClusterer.java 1.7 -> 1.8
diff -u -r1.7 -r1.8
--- HPSEcal1BitClusterer.java	23 Aug 2011 17:08:10 -0000	1.7
+++ HPSEcal1BitClusterer.java	23 Aug 2011 17:28:19 -0000	1.8
@@ -18,7 +18,6 @@
 import org.lcsim.util.Driver;
 import org.lcsim.util.lcio.LCIOConstants;
 
-//import org.lcsim.hps.util.RingBuffer;
 /**
  * Creates clusters from CalorimeterHits in the HPSEcal detector.
  * 
@@ -33,7 +32,7 @@
     HPSEcal ecal;
     String ecalCollectionName;
     String ecalName;
-    String digitizedCollectionName = "EcalDigitizedHits";
+    String rawCollectionName = "EcalRawHits";
     String clusterCollectionName = "EcalClusters";
     // Threshold E for discriminator.
     double hitEMin = .05;
@@ -47,7 +46,6 @@
     int clock;
     //number of bunches in trigger cycle
     int triggerCycle = 4;
-    ECalSimpleReadout digitizer = null;
 
     public HPSEcal1BitClusterer() {
     }
@@ -56,8 +54,8 @@
         this.clusterCollectionName = clusterCollectionName;
     }
 
-    public void setDigitizedCollectionName(String digitizedCollectionName) {
-        this.digitizedCollectionName = digitizedCollectionName;
+    public void setRawCollectionName(String RawCollectionName) {
+        this.rawCollectionName = rawCollectionName;
     }
 
     public void setHitEMin(double hitEMin) {
@@ -82,7 +80,6 @@
 
     public void startOfData() {
         clock = 0;
-        digitizer = new ECalSimpleReadout(ecal);
         if (ecalCollectionName == null) {
             throw new RuntimeException("The parameter ecalCollectionName was not set!");
         }
@@ -95,7 +92,6 @@
     public void detectorChanged(Detector detector) {
         // Get the Subdetector.
         ecal = (HPSEcal2) detector.getSubdetector(ecalName);
-        digitizer.setEcal(ecal);
 
         // Cache ref to neighbor map.
         neighborMap = ecal.getNeighborMap();
@@ -112,13 +108,13 @@
     public void process(EventHeader event) {
         //System.out.println(this.getClass().getCanonicalName() + " - process");
 
-        // Get the list of digitized ECal hits.
-        List<CalorimeterHit> hits = event.get(CalorimeterHit.class, digitizedCollectionName);
+        // Get the list of raw ECal hits.
+        List<CalorimeterHit> hits = event.get(CalorimeterHit.class, rawCollectionName);
 
         // New Cluster list to be added to event.
         List<Cluster> clusters = new ArrayList<Cluster>();
 
-        //if there are digitized hits, run clustering
+        //if there are raw hits, run clustering
         if (hits != null) {
             // Hit map.
             Map<Long, CalorimeterHit> hitMap = new HashMap<Long, CalorimeterHit>();
CVSspam 0.2.8